% Compute the Harris criterion for each pixel
% Inputs
%    k      Constant used in the Harris criterion
%    Psize  Size of the patches we use
%    Ix     Image gradient in x direction
%    Iy     Image gradient in y direction
% Output
%    C      Value for the Harris criterion in each pixel

function C = harris(k,Psize,Ix,Iy)
[W,L] = size(Ix);
C = zeros(W,L);           % Make some room
a = ceil(Psize/2);
al = floor(Psize/2);
IxIx = Ix.^2;
IxIy = Ix.*Iy;
IyIy = Iy.^2;
for i=a:1:W-a             % x, Do not bother about the border
  for j=a:1:L-a           % y 
    IxIxpart = IxIx(i-al:1:i+al,j-al:1:j+al);
    IxIypart = IxIy(i-al:1:i+al,j-al:1:j+al);
    IyIypart = IyIy(i-al:1:i+al,j-al:1:j+al);
    GNow = [sum(sum(IxIxpart))   sum(sum(IxIypart));
            sum(sum(IxIypart))   sum(sum(IyIypart))];
    C(i,j) = det(GNow) + k*(trace(GNow))^2;     % Compute the Harris criterion
  end
end
