% Perform template matching between images. Find the best position of a certain 
% patch within a larger image.
% Inputs
%    I1        Image 1, the big image as a 2D matrix
%    patch     The patch to match against the image I1
%
% Outputs
%    pos.x     The position in image I1 best matching the patch. (the center of the patch)
%    pos.y     Same as above, but y position
%    pos.dpm   The "degree of match", e.g., for the NCC a value between -1 and 1

function pos = tmatcher(I1,patch)

Psize = size(patch,1);         % Determine patch size
N = Psize^2;                   % Number of pixels in the patch
[max_r, max_c] = size(I1);     % [rows, columns] of image I1
a = ceil(Psize/2);
al = floor(Psize/2);
loopr = max_r - 2*al;
loopc = max_c - 2*al;
NCC = zeros(loopr,loopc);
patchmean = (1/N)*sum(sum(patch));
patchdiff = patch - patchmean;
pds = sum(sum(patchdiff.^2));

% Loop over all possible locations in image I1
for i = a:loopr-a         % rows in the I1 image
  for j = a:loopc-a       % columns in the I1 image
    I1patch = I1(i-al:i+al,j-al:j+al);
    I1mean = (1/N)*sum(sum(I1patch));
    I1diff = I1patch - I1mean;
    if sum(sum(I1diff)) == 0         % No variation in the original image
      NCC(i,j) = -1;
    else
      NCC(j,i) = sum(sum(I1diff.*patchdiff))/sqrt(sum(sum(I1diff.^2))*pds);
    end
  end
end

%NCC = normxcorr2(patch,I1);

[pos.dom, ind] = maxmat(NCC);
pos.x = ind(1);    % OBS! Different coordinate systems
pos.y = ind(2);    % OBS! Different coordinate systems


pos.NCC = NCC;