function [x,P,patches,visible,status] = SFTimeStep(x,P,meas,patches,par,status)
%SFTIMESTEP   Sensor fusion. All the operations that are performed during
%   one time step of the sensor fusion process are present here.
%
%   Input
%      x           State mean
%      P           State covariance
%      meas        Struct containing the measurements
%      patches     Patches from landmarks
%      par         Parameters
%      status      status vector
%
%   Output
%      x           State mean
%      P           State covariance
%      meas        Struct containing the measurements
%      patches     Patches from landmarks
%      visible     Index to the visible landmarks
%      status      status vector

% Compare the flow below to what was introduced during Lecture 3

%=============================================
%===  Inertial and barometer measurements  ===
%=============================================
t = status.t;
u = [meas.ya(:,t);meas.yw(:,t)];
y = meas.yhp(t);
[xnew, Pnew] = IMUBarUpdate(x(1:par.nps), P(1:par.nps,1:par.nps), u, y, par);
x = [xnew; x(par.nps+1:end)];
P = [Pnew P(1:par.nps,par.nps+1:end); P(par.nps+1:end,:)];
visible = [];
%=============================
%===  Vision measurements  ===
%=============================
% Check if a camera measurement is available
if (((meas.im_time(status.ctime)-meas.imu_time(t))<1e-3) && t > 1)
  disp(['Time = ',num2str(status.t)]);
  I = meas.yim{status.ctime};

% Predict the landmark position
   yhatf = predictLandmarks(x, par);  %Predicted feature coordinates in image with focal length 1.

% Data association
   [yfm, yfp, yhatfp, yhatfp_noinit, visible, visInnovation] = dataAssociation(yhatf, I, x, par, patches, status);
   status.visibleOld = visible;

% Measurement update based on the vision information
  if ~isempty(visInnovation)
    [x, P, S] = visionStateUpdate(x, P, visInnovation(:), par, visible);
  end;

% Plot patches
  if par.plotOnOff
    plotpaches(I, yhatfp, yfp, S, visible, status.visibleOld, 3, par, t);
  end;
 
% Search for new landmarks and initialize
  if status.findNewLandmarks && (par.max_patch-length(visible)>0)
    [x, P, patches] = searchNewLandmarks(x, P, patches, yhatfp_noinit, I, visible, par);
  end;
  status.ctime = status.ctime+1;
end;
end