%
% patches = extPatches(I,C,par,N)
% Select which patches to use
% Inputs
%    I                   Image
%    C                   Harris criterion matrix
%    par.max_patch       Maximum number of patches
%    par.min_sep         Minumum separation between map entries (features)
%    par.Harris_th       Lower threshold for the Harris criterion
%    par.Psize           Patch size (always odd)
%    N                   Number of patches that should be returned (optional)
% Outputs
%    patches.c   center points for the patches (i.e. the point 
%                given from the Harris criterion)  [x, y]
%    patches.I   Patches

function patches = extPatches(I,C,par,varargin)
  if nargin>3
    N=varargin{1};
  else
    N = par.max_patch;
  end
  th = par.Harris_th;
  Psize = par.Psize;   min_sep = par.min_sep;
  i = 1;
  [Mmax, ind] = maxmat(C);
  a = floor(Psize/2);
  [nx, ny] = size(C);
  while (i<=N)&&(Mmax>=th)
    patches.c(i,1) = ind(2);     % Due to the different def of the image coordinate system
    patches.c(i,2) = ind(1);
    patches.I(:,:,i) = I(ind(1)-a:ind(1)+a,ind(2)-a:ind(2)+a);

    x_start = max(1,ind(1)-min_sep);
    x_end   = min(nx,ind(1)+min_sep);
    y_start = max(1,ind(2)-min_sep);
    y_end   = min(ny,ind(2)+min_sep);
    C(x_start:x_end,y_start:y_end) = zeros(x_end-x_start+1,y_end-y_start+1);
    
    [Mmax, ind] = maxmat(C);
    i = i+1;
  end

  if i==1    % No patches were selected
    patches.c=[];
    patches.I=[];
  end
  
end
