function [x, P, patches] = extractLandmarksInit(I, x, P, par)
%EXTRACTLANDMARKS   Extract new landmarks
%   Input
%      I        Image
%      x        State vector
%      P        Covariance matrix
%      par      Parameters
%   Output
%      x        State vector
%      P        Covariance matrix
%      patches  Currently existing patches

Psize = par.Psize;
grad = iGradient(I,par.sigma_smooth,par.sigma_diff);      % Compute image gradients
C = harris(par.Harris_k,par.Psize,grad.Ix,grad.Iy);       % Compute the Harris criterion
patches = extPatches(I,C,par);                            % Select patches to use
min_sep = par.min_sep;      % Minimum separation between two features
Tsize = par.search_region;  % Size of the seach region around each feature

% figure
% imshow(I)
% hold on
% plot(patches.c(:,1), patches.c(:,2),'bs','MarkerSize',7)
% hold off
% figure
% surf(C), shading flat 

% Initialize map entries
nf = size(patches.c,1);
for i = 1:size(patches.c,1)
  % Correct for calibration, i.e., allow us to make use of a standard pinhole model
  ym = normalize(patches.c(i,:)',par.cam.fc,par.cam.cc,par.cam.kc,par.cam.alpha_c);
  zf = par.zf0;
  xf = ym(1)*zf;
  yf = ym(2)*zf;
  hc = [xf yf zf]';             % Position of the feature expressed in the camera cs
  Rec = (Rq(par.q_bc)'*Rq(x{1}(7:10)))';   % Rce = RcbRbe = (Rbc)'Rbe
  fpos = Rec*hc + x{1}(1:3);    % Earth coodinate system
  x{1} = [x{1}; fpos];          % Augment the state vector
  P{1} = blkdiag(P{1},Rec'*par.Pf0*Rec);
end

if nf~=0
  Rc = par.Rc*eye(2*nf);
  for i = 1:size(patches.c,1)
    S(:,:,i) = Rc(1+(i-1)*2:2+(i-1)*2,1+(i-1)*2:2+(i-1)*2);
  end;
  vis_indold=[1:1:size(patches.c,1)];
else
  S = [];
end
