function plotpaches(I, yhatfp, yfp, S, visible, visibleOld, fignr, par, t)
%PLOTPATCHES   Plots the matched patches, the search regions and the innovation covariance.
%   Input
%      I            Image
%      yhatfp       Predicted feature position in pixels
%      yfp          Measured feature position in pixels
%      visible      Index to the matched landmarks in the current image
%      visibleOld   Index to the matched landmarks in the previous image
%      fignr        Number to the figure in which to plot
%      par          Parameters
%      t            Time

  Psize = par.Psize;          % Patch size, the size of the patches are Psize*Psize pixels
  Tsize = par.search_region;  % Size of the seach region around each feature

  figure(fignr);
  imshow(I)
  hold on
  title(['t=',num2str(t)]);

  % Plot the innovation covariance ellipses
  for i=1:size(S,3)
    S_i = S(:,:,i);
    [v,ev] = eig(S_i);
    axis1_mag = sqrt(ev(1,1))*3;
    axis2_mag = sqrt(ev(2,2))*3;
    angleinc=2*pi/10;
    angle=0:angleinc:2*pi;
    for j=1:length(angle)
      x_ellipse(j)=axis1_mag*cos(angle(j));
      y_ellipse(j)=axis2_mag*sin(angle(j));
    end;
    % Rotate the ellipse
    phi = atan(v(2)/v(1));
    R = [cos(phi) -sin(phi);
      sin(phi) cos(phi)];
    tmp = R*[x_ellipse; y_ellipse];
    x_ellipse = tmp(1,:);   y_ellipse = tmp(2,:);
    ellipse_x = par.cam.fc(1).*x_ellipse + yhatfp(1,visibleOld(i));   % Scale and translate the ellipse
    ellipse_y = par.cam.fc(2).*y_ellipse + yhatfp(2,visibleOld(i));   % Scale and translate the ellipse
    plot(ellipse_x,ellipse_y,'b')                                     % Plot the ellipse
  end;
  
  for i=1:length(visible)
    j=visible(i);
    plot(yhatfp(1,j)-Tsize:yhatfp(1,j)+Tsize,yhatfp(2,j)-Tsize,'k')                    % Search Window
    plot(yhatfp(1,j)-Tsize:yhatfp(1,j)+Tsize,yhatfp(2,j)+Tsize,'k')                    % Search Window
    plot(yhatfp(1,j)-Tsize,yhatfp(2,j)-Tsize:yhatfp(2,j)+Tsize,'k')                    % Search Window
    plot(yhatfp(1,j)+Tsize,yhatfp(2,j)-Tsize:yhatfp(2,j)+Tsize,'k')                    % Search Window
    plot(yfp(1,i)-floor(Psize/2):yfp(1,i)+floor(Psize/2),yfp(2,i)-floor(Psize/2),'r')  % Matched patch
    plot(yfp(1,i)-floor(Psize/2):yfp(1,i)+floor(Psize/2),yfp(2,i)+floor(Psize/2),'r')  % Matched patch
    plot(yfp(1,i)-floor(Psize/2),yfp(2,i)-floor(Psize/2):yfp(2,i)+floor(Psize/2),'r')  % Matched patch
    plot(yfp(1,i)+floor(Psize/2),yfp(2,i)-floor(Psize/2):yfp(2,i)+floor(Psize/2),'r')  % Matched patch
  end;
end