function showdata(infile,varargin)
%
% Shows converted data
% Ex showdata('helidata.mat');
%
  load(infile);
  if nargin>1
    vision=varargin{1};
  else
    vision=1;
  end
  
  % Plot accelerometer data
  figure;
  plot(meas.imu_time,meas.ya');
  xlabel('Time [s]');
  title('Accelerations');
  
  % Plot accelerometer fft
  acc=detrend(meas.ya')';
  N=length(acc);
  N2=floor(N/2);
  acc_fft=fft(acc,[],2);
  figure;
  subplot(3,1,1);
  plot([0:N2-1]*1/(meas.Timu*N),abs(acc_fft(1,1:N2)),'k');
  ylabel('x');
  title('Accelerations');
  subplot(3,1,2);
  plot([0:N2-1]*1/(meas.Timu*N),abs(acc_fft(2,1:N2)),'k');
  ylabel('y');
  subplot(3,1,3);
  plot([0:N2-1]*1/(meas.Timu*N),abs(acc_fft(3,1:N2)),'k');
  ylabel('z');
  xlabel('Frequency [Hz]')
  print(gcf,'-deps','ya_fft.eps')
  
  % Plot angular velocities
  figure;
  subplot(3,1,1);
  plot(meas.imu_time,meas.yw(1,:),'k');
  ylabel('x');
  title('Angular velocities');
  subplot(3,1,2);
  plot(meas.imu_time,meas.yw(2,:),'k');
  ylabel('y');
  subplot(3,1,3);
  plot(meas.imu_time,meas.yw(3,:),'k');
  ylabel('z');
  xlabel('Time [s]');
  
  % Plot angular velocity fft
  omega=detrend(meas.yw')';
  N=length(omega);
  N2=floor(N/2);
  omega_fft=fft(omega,[],2);
  figure;
  subplot(3,1,1);
  plot([0:N2-1]*1/(meas.Timu*N),abs(omega_fft(1,1:N2)),'k');
  ylabel('x');
  title('Angular velocities');
  subplot(3,1,2);
  plot([0:N2-1]*1/(meas.Timu*N),abs(omega_fft(2,1:N2)),'k');
  ylabel('y');
  subplot(3,1,3);
  plot([0:N2-1]*1/(meas.Timu*N),abs(omega_fft(3,1:N2)),'k');
  ylabel('z');  
  xlabel('Frequency [Hz]')
  print(gcf,'-deps','yw_fft.eps')
  
  % Plot reference trajectory
  figure;
  plot(ref.p(1,:),ref.p(2,:));
  xlabel('Latitude');
  ylabel('Longitude');
  title('Reference trajectory');
  
  % Show image sequence
  if vision
    f=figure;
    for i=1:length(meas.yim)
      figure(f);
      imshow(meas.yim{i});
      title(['T=' num2str(meas.im_time(i))])
      pause(meas.Tim);
    end
  end
  
end